@@ -1,7 +1,7 @@
 package Locale::CLDR::Collator;
 
 use version;
-our $VERSION = version->declare('v0.28.1');
+our $VERSION = version->declare('v0.28.2');
 
 use v5.10.1;
 use mro 'c3';
@@ -164,7 +164,7 @@ sub generate_ce {
 	my $base;
 	
 	if ($character =~ /\p{Unified_Ideograph}/) {
-		if ($character =~ /\p{Block=CJK_Unified_Ideograph}/ || $character =~ /\p{Block=CJK_Compatibility_Ideographs}/) {
+		if ($character =~ /\p{Block=CJK_Unified_Ideographs}/ || $character =~ /\p{Block=CJK_Compatibility_Ideographs}/) {
 			$base = 0xFB40;
 		}
 		else {
